==> qtjambi-uic-5.15.17-sources.jar: io/qt/uic/ui4/DomConnectionHint.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomConnectionHint</code></p>
 */
public class DomConnectionHint extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>DomConnectionHint()</code></p>
     */
    public DomConnectionHint(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomConnectionHint instance);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>attributeType()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeType(){
        return attributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>clearAttributeType()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeType(){
        clearAttributeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeType_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>clearElementX()</code></p>
     */
    @QtUninvokable
    public final void clearElementX(){
        clearElementX_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementX_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>clearElementY()</code></p>
     */
    @QtUninvokable
    public final void clearElementY(){
        clearElementY_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementY_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>elementX()const</code></p>
     */
    @QtUninvokable
    public final int elementX(){
        return elementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>elementY()const</code></p>
     */
    @QtUninvokable
    public final int elementY(){
        return elementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>hasAttributeType()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeType(){
        return hasAttributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>hasElementX()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementX(){
        return hasElementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>hasElementY()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementY(){
        return hasElementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>setAttributeType(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeType(java.lang.@NonNull String a){
        setAttributeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>setElementX(int)</code></p>
     */
    @QtUninvokable
    public final void setElementX(int a){
        setElementX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementX_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>setElementY(int)</code></p>
     */
    @QtUninvokable
    public final void setElementY(int a){
        setElementY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementY_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomConnectionHint::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomConnectionHint(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.10-sources.jar: io/qt/uic/ui4/DomConnectionHint.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomConnectionHint</p>
 */
public class DomConnectionHint extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomConnectionHint(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomConnectionHint instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeType(){
        return attributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeType(){
        clearAttributeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeType_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementX(){
        clearElementX_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementX_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementY(){
        clearElementY_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementY_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementX(){
        return elementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementX_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementY(){
        return elementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementY_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeType(){
        return hasAttributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementX(){
        return hasElementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementX_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementY(){
        return hasElementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementY_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeType(java.lang.String a){
        setAttributeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementX(int a){
        setElementX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementX_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementY(int a){
        setElementY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementY_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomConnectionHint(QPrivateConstructor p) { super(p); } 
    
}
